@@ -152,17 +152,11 @@ var LibraryManager = {
       libraries.push('library_glemu.js');
     }
 
-    if (STANDALONE_WASM) {
-      libraries.push('library_wasi.js');
-    }
+    libraries.push('library_wasi.js');
 
     libraries = libraries.concat(additionalLibraries);
 
     if (BOOTSTRAPPING_STRUCT_INFO) libraries = ['library_bootstrap_structInfo.js', 'library_formatString.js'];
-    if (ONLY_MY_CODE) {
-      libraries.length = 0;
-      LibraryManager.library = {};
-    }
 
     // TODO: deduplicate libraries (not needed for correctness, but avoids unnecessary work)
 
@@ -291,7 +285,7 @@ var LibraryManager = {
   }
 };
 
-if (!BOOTSTRAPPING_STRUCT_INFO && !ONLY_MY_CODE) {
+if (!BOOTSTRAPPING_STRUCT_INFO) {
   // Load struct and define information.
   var temp = JSON.parse(read(STRUCT_INFO));
   C_STRUCTS = temp.structs;
