@@ -925,7 +925,8 @@ function createWasm() {
     // In pure wasm mode the memory is created in the wasm (not imported), and
     // then exported.
     // TODO: do not create a Memory earlier in JS
-    updateGlobalBufferAndViews(exports['memory'].buffer);
+    wasmMemory = exports['memory'];
+    updateGlobalBufferAndViews(wasmMemory.buffer);
 #if ASSERTIONS
     writeStackCookie();
 #endif
